==> jenkins-core-1.642.3-sources.jar: jenkins/security/HudsonPrivateSecurityRealmTagLib.java <==

package jenkins.security;

import java.util.Map;
import groovy.lang.Closure;
import org.kohsuke.stapler.jelly.groovy.TagLibraryUri;
import org.kohsuke.stapler.jelly.groovy.TypedTagLibrary;

@TagLibraryUri("/hudson/security/HudsonPrivateSecurityRealm")
public interface HudsonPrivateSecurityRealmTagLib
    extends TypedTagLibrary
{


    /**
     * 
     */
    void index(Map args, Closure body);

    /**
     * 
     */
    void index(Closure body);

    /**
     * 
     */
    void index(Map args);

    /**
     * 
     */
    void index();

    /**
     * 
     */
    void loginLink(Map args, Closure body);

    /**
     * 
     */
    void loginLink(Closure body);

    /**
     * 
     */
    void loginLink(Map args);

    /**
     * 
     */
    void loginLink();

    /**
     * 
     */
    void firstUser(Map args, Closure body);

    /**
     * 
     */
    void firstUser(Closure body);

    /**
     * 
     */
    void firstUser(Map args);

    /**
     * 
     */
    void firstUser();

    /**
     * 
     */
    void signup(Map args, Closure body);

    /**
     * 
     */
    void signup(Closure body);

    /**
     * 
     */
    void signup(Map args);

    /**
     * 
     */
    void signup();

    /**
     * 
     */
    void success(Map args, Closure body);

    /**
     * 
     */
    void success(Closure body);

    /**
     * 
     */
    void success(Map args);

    /**
     * 
     */
    void success();

    /**
     * 
     */
    void addUser(Map args, Closure body);

    /**
     * 
     */
    void addUser(Closure body);

    /**
     * 
     */
    void addUser(Map args);

    /**
     * 
     */
    void addUser();

    /**
     * 
     */
    void sidepanel(Map args, Closure body);

    /**
     * 
     */
    void sidepanel(Closure body);

    /**
     * 
     */
    void sidepanel(Map args);

    /**
     * 
     */
    void sidepanel();

    /**
     * 
     */
    void signupWithFederatedIdentity(Map args, Closure body);

    /**
     * 
     */
    void signupWithFederatedIdentity(Closure body);

    /**
     * 
     */
    void signupWithFederatedIdentity(Map args);

    /**
     * 
     */
    void signupWithFederatedIdentity();

    /**
     * 
     */
    void config(Map args, Closure body);

    /**
     * 
     */
    void config(Closure body);

    /**
     * 
     */
    void config(Map args);

    /**
     * 
     */
    void config();

    /**
     * 
     */
    void _entryForm(Map args, Closure body);

    /**
     * 
     */
    void _entryForm(Closure body);

    /**
     * 
     */
    void _entryForm(Map args);

    /**
     * 
     */
    void _entryForm();

}

==> jenkins-core-2.414.3-sources.jar: jenkins/security/HudsonPrivateSecurityRealmTagLib.java <==

package jenkins.security;

import java.util.Map;
import groovy.lang.Closure;
import org.kohsuke.stapler.jelly.groovy.TagLibraryUri;
import org.kohsuke.stapler.jelly.groovy.TypedTagLibrary;

@TagLibraryUri("/hudson/security/HudsonPrivateSecurityRealm")
public interface HudsonPrivateSecurityRealmTagLib
    extends TypedTagLibrary
{


    /**
     * 
     */
    void addUser(Map args, Closure body);

    /**
     * 
     */
    void addUser(Closure body);

    /**
     * 
     */
    void addUser(Map args);

    /**
     * 
     */
    void addUser();

    /**
     * 
     */
    void firstUser(Map args, Closure body);

    /**
     * 
     */
    void firstUser(Closure body);

    /**
     * 
     */
    void firstUser(Map args);

    /**
     * 
     */
    void firstUser();

    /**
     * 
     */
    void config(Map args, Closure body);

    /**
     * 
     */
    void config(Closure body);

    /**
     * 
     */
    void config(Map args);

    /**
     * 
     */
    void config();

    /**
     * 
     */
    void signupWithFederatedIdentity(Map args, Closure body);

    /**
     * 
     */
    void signupWithFederatedIdentity(Closure body);

    /**
     * 
     */
    void signupWithFederatedIdentity(Map args);

    /**
     * 
     */
    void signupWithFederatedIdentity();

    /**
     * 
     */
    void signup(Map args, Closure body);

    /**
     * 
     */
    void signup(Closure body);

    /**
     * 
     */
    void signup(Map args);

    /**
     * 
     */
    void signup();

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryForm(Map args, Closure body);

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryForm(Closure body);

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryForm(Map args);

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryForm();

    /**
     * 
     */
    void index(Map args, Closure body);

    /**
     * 
     */
    void index(Closure body);

    /**
     * 
     */
    void index(Map args);

    /**
     * 
     */
    void index();

    /**
     * 
     */
    void success(Map args, Closure body);

    /**
     * 
     */
    void success(Closure body);

    /**
     * 
     */
    void success(Map args);

    /**
     * 
     */
    void success();

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryFormPage(Map args, Closure body);

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryFormPage(Closure body);

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryFormPage(Map args);

    /**
     * 
     *     
     *     
     *     
     *     
     *     
     *   
     * 
     */
    void _entryFormPage();

    /**
     * 
     */
    void loginLink(Map args, Closure body);

    /**
     * 
     */
    void loginLink(Closure body);

    /**
     * 
     */
    void loginLink(Map args);

    /**
     * 
     */
    void loginLink();

}
